﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO.Ports;
using Opticon;

namespace OseCommApp.CSharp
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            comboPort.Items.AddRange( System.IO.Ports.SerialPort.GetPortNames());
            comboPort.SelectedIndex = 0;

            comboBaudrate.SelectedIndex = 0;    // 115200 baud
            comboIrda.SelectedIndex = 1;        // litelink Irda adapter
            comboComType.SelectedIndex = 0;     // Continuous
            numericSuccessNoAnswer.Enabled = false;

            buttonStopProtocol.Enabled = false;
        }

        private void comboComType_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (comboComType.SelectedIndex == 0)
                numericSuccessNoAnswer.Enabled = false;
            else
                numericSuccessNoAnswer.Enabled = true;
        }

        private void buttonStartProtocol_Click(object sender, EventArgs e)
        {
            if (oseComm1.IsProtocolRunning)
                return;
            string port = comboPort.SelectedItem.ToString();
            oseComm1.COMport = Convert.ToInt16(port.Substring(3));
            oseComm1.Baudrate = (OseComm.Baud)Convert.ToInt32(comboBaudrate.SelectedItem.ToString());
            oseComm1.IrdaAdapter = (OseComm.IrdaDevice) comboIrda.SelectedIndex;

            // Start the OseComm protocol
            if (oseComm1.StartProtocol((OseComm.CommType)comboComType.SelectedIndex, (int)numericSuccessNoAnswer.Value))
            {
                buttonStopProtocol.Enabled = true;
                buttonStartProtocol.Enabled = false;
                 
                comboPort.Enabled = false;
                comboBaudrate.Enabled = false;
                comboIrda.Enabled = false;
                comboComType.Enabled = false;
                numericSuccessNoAnswer.Enabled = false;
            }
            else
                MessageBox.Show("Cannot start the OseComm protocol\nIs the COM port already in use?", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }

        private void buttonStopProtocol_Click(object sender, EventArgs e)
        {
            if (oseComm1.IsProtocolRunning)
            {
                // Stop the OseComm Protocol
                oseComm1.StopProtocol();
                progressFileTransfer.Value = 0;

                buttonStopProtocol.Enabled = false;
                buttonStartProtocol.Enabled = true;

                comboPort.Enabled = true;
                comboBaudrate.Enabled = true;
                comboIrda.Enabled = true;
                comboComType.Enabled = true;
                if (comboComType.SelectedIndex != 0)
                    numericSuccessNoAnswer.Enabled = true;
            }
        }

        private void buttonGetTimeDate_Click(object sender, EventArgs e)
        {
            if (oseComm1.AddGetTerminalTimeDate(OseComm.TimeDateFmt.FmthhmmssDDMMYYYYY))
                listOptions.Items.Add("Get Time Date");
        }

        private void buttonSetTimeDate_Click(object sender, EventArgs e)
        {
            oseComm1.AddSetLocalTimeDate();
            listOptions.Items.Add("Set Time Date");
        }

        private void buttonClearOptions_Click(object sender, EventArgs e)
        {
            oseComm1.ClearProtocolTaskList();
            listOptions.Items.Clear();
        }

        private void buttonGetOsVersion_Click(object sender, EventArgs e)
        {
            oseComm1.AddGetTerminalOSVersion();
            listOptions.Items.Add("Get OS Version");
        }

        private void buttonGetAppVersion_Click(object sender, EventArgs e)
        {
            oseComm1.AddGetTerminalApplicationVersion();
            listOptions.Items.Add("Get Application version");
        }

        private void buttonTerminalToPC_Click(object sender, EventArgs e)
        {
            FileForm form = new FileForm();
            form.FormText = "Send File From Terminal to PC";
            form.UseDownType = true;
            if (form.ShowDialog() == DialogResult.OK)
            {
                if (oseComm1.AddReceiveFileFromTerminal(form.PcFilename,
                                                     (OseComm.DownType)form.DownloadType,
                                                     form.TerminalFilename,
                                                     (short)form.TerminalDrive,
                                                     form.ContinueWhenNotAvailable))
                {
                    listOptions.Items.Add("Send file from Terminal To PC");
                }
                else
                {
                    MessageBox.Show("Error in settings to receive file from Terminal", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
                
            }
        }

        private void buttonPCToTerminal_Click(object sender, EventArgs e)
        {
            FileForm form = new FileForm();
            form.FormText = "Send File From PC to Terminal";
            if (form.ShowDialog() == DialogResult.OK)
            {
                if (oseComm1.AddTransmitFileToTerminal(form.PcFilename, 
                                                    form.TerminalFilename,
                                                    (short)form.TerminalDrive,
                                                    form.ContinueWhenNotAvailable))
                {
                    listOptions.Items.Add("Send file from PC to Terminal");
                }
                else
                {
                    MessageBox.Show("Error in settings to send file to Terminal", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        private void buttonListFiles_Click(object sender, EventArgs e)
        {
            QueryForm form = new QueryForm();
            form.FormText = "List Files";
            form.TerminalFilename = "*.*";
            if (form.ShowDialog() == DialogResult.OK)
            {
                if (oseComm1.AddGetTerminalFileList(form.TerminalFilename, (short)form.TerminalDrive))
                {
                    listOptions.Items.Add("List files");
                }
                else
                {
                    MessageBox.Show("Error in settings for List Files", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        private void buttonDeleteFiles_Click(object sender, EventArgs e)
        {
            QueryForm form = new QueryForm();
            form.FormText = "Delete Files";
            form.TerminalFilename = "*.*";
            if (form.ShowDialog() == DialogResult.OK)
            {
                if (oseComm1.AddDeleteTerminalFiles(form.TerminalFilename, (short)form.TerminalDrive))
                {
                    listOptions.Items.Add("Delete files");
                }
                else
                {
                    MessageBox.Show("Error in settings for List Files", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        private void buttonClearLog_Click(object sender, EventArgs e)
        {
            listStatus.Items.Clear();
        }

        private void oseComm1_Connected(object sender, ConnectedEventArgs e)
        {
            listStatus.Items.Insert(0, String.Format("Connected to ID: {0}", e.TerminalID));
        }

        private void oseComm1_Progress(object sender, ProgressEventArgs e)
        {
            progressFileTransfer.Value = e.Progress;
        }

        private void oseComm1_StatusInformation(object sender, StatusInformationEventArgs e)
        {
            listStatus.Items.Insert(0, e.Information);
        }
    }
}
